==> edge-login-ui-rn-0.9.23.tgz: package/lib/components/modals/SecurityAlertsModal.js <==
import * as React from 'react';
import { StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import { AirshipModal } from 'react-native-airship';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import s from '../../common/locales/strings';
import { withTheme } from '../services/ThemeContext';
import { ModalCloseArrow } from '../themed/ModalParts';
class SecurityAlertsModalComponent extends React.Component {
    render() {
        const { bridge, theme } = this.props;
        const styles = getStyles(theme);
        // Since we can't add native dependencies without a major version bump,
        // we rely on the GUI to sneak this one to us:
        // @ts-expect-error
        const { ReactNativeBlurView } = global;
        const underlay = typeof ReactNativeBlurView === 'function' ? (React.createElement(ReactNativeBlurView, { blurType: theme.modalBlurType, style: StyleSheet.absoluteFill })) : ('rgba(0, 0, 0, 0.75)');
        // We use AirshipModal directly so we can implement our custom appearance.
        return (React.createElement(AirshipModal, { bridge: bridge, onCancel: () => bridge.resolve(undefined), padding: theme.rem(0.5), underlay: underlay, borderRadius: 0 },
            React.createElement(View, { style: styles.iconCircle },
                React.createElement(FontAwesome, { name: "exclamation-triangle", size: theme.rem(2), color: theme.primaryText })),
            React.createElement(Text, { style: styles.titleText }, s.strings.alert_modal_title),
            this.renderList(),
            React.createElement(ModalCloseArrow, { onPress: () => bridge.resolve(undefined) })));
    }
    renderList() {
        const { messages } = this.props;
        const out = [];
        let isFirst = true;
        for (const username of Object.keys(messages)) {
            const { otpResetPending } = messages[username];
            if (otpResetPending) {
                out.push(this.renderRow(username, true, isFirst));
                isFirst = false;
            }
        }
        for (const username of Object.keys(messages)) {
            const { pendingVouchers = [] } = messages[username];
            if (pendingVouchers.length > 0) {
                out.push(this.renderRow(username, false, isFirst));
                isFirst = false;
            }
        }
        return out;
    }
    renderRow(username, isReset, isFirst) {
        const { bridge, theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(TouchableOpacity, { key: (isReset ? 'reset:' : 'voucher:') + username, style: isFirst ? styles.row : styles.rowBorder, onPress: () => {
                this.props.selectUser(username);
                bridge.resolve(undefined);
            } },
            React.createElement(FontAwesome, { color: isReset
                    ? theme.securityAlertModalDangerIcon
                    : theme.securityAlertModalWarningIcon, name: "exclamation-triangle", size: theme.rem(1.5), style: styles.rowIcon }),
            React.createElement(Text, { style: styles.rowText },
                React.createElement(Text, { style: styles.bold },
                    isReset
                        ? s.strings.alert_modal_reset
                        : s.strings.alert_modal_voucher,
                    username),
                s.strings.alert_modal_action),
            React.createElement(AntDesignIcon, { color: theme.securityAlertModalText, name: "right", size: theme.rem(1), style: styles.rowIcon })));
    }
}
const iconRem = 3.5;
const getStyles = cacheStyles((theme) => ({
    iconCircle: {
        // Layout:
        alignSelf: 'center',
        marginTop: -theme.rem(0.5 + iconRem / 2),
        marginBottom: theme.rem(0.5),
        height: theme.rem(iconRem),
        width: theme.rem(iconRem),
        // Visuals:
        backgroundColor: theme.securityAlertModalHeaderCircle,
        borderRadius: theme.rem(iconRem / 2),
        // Children:
        alignItems: 'center',
        justifyContent: 'center',
        overflow: 'hidden'
    },
    titleText: {
        color: theme.securityAlertModalText,
        fontFamily: theme.fontFamily,
        fontSize: theme.rem(1.2),
        margin: theme.rem(0.5),
        textAlign: 'center'
    },
    row: {
        alignItems: 'center',
        flexDirection: 'row'
    },
    rowBorder: {
        alignItems: 'center',
        borderTopColor: theme.securityAlertModalRowBorder,
        borderTopWidth: theme.rem(0.0625),
        flexDirection: 'row',
        marginTop: theme.rem(0.5),
        paddingTop: theme.rem(0.5)
    },
    rowIcon: {
        margin: theme.rem(0.5)
    },
    rowText: {
        color: theme.securityAlertModalText,
        flexGrow: 1,
        flexShrink: 1,
        fontFamily: theme.fontFamily,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5)
    },
    bold: {
        fontWeight: 'bold'
    }
}));
export const SecurityAlertsModal = withTheme(SecurityAlertsModalComponent);

==> edge-login-ui-rn-0.10.11.tgz: package/lib/components/modals/SecurityAlertsModal.js <==
import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import s from '../../common/locales/strings';
import { withTheme } from '../services/ThemeContext';
import { ModalCloseArrow } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
import { TitleText } from '../themed/ThemedText';
class SecurityAlertsModalComponent extends React.Component {
    render() {
        const { bridge } = this.props;
        return (React.createElement(ThemedModal, { bridge: bridge, warning: true, onCancel: () => bridge.resolve(undefined) },
            React.createElement(TitleText, null, s.strings.alert_modal_title),
            this.renderList(),
            React.createElement(ModalCloseArrow, { onPress: () => bridge.resolve(undefined) })));
    }
    renderList() {
        const { messages } = this.props;
        const out = [];
        let isFirst = true;
        for (const username of Object.keys(messages)) {
            const { otpResetPending } = messages[username];
            if (otpResetPending) {
                out.push(this.renderRow(username, true, isFirst));
                isFirst = false;
            }
        }
        for (const username of Object.keys(messages)) {
            const { pendingVouchers = [] } = messages[username];
            if (pendingVouchers.length > 0) {
                out.push(this.renderRow(username, false, isFirst));
                isFirst = false;
            }
        }
        return out;
    }
    renderRow(username, isReset, isFirst) {
        const { bridge, theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(TouchableOpacity, { key: (isReset ? 'reset:' : 'voucher:') + username, style: isFirst ? styles.row : styles.rowBorder, onPress: () => {
                this.props.selectUser(username);
                bridge.resolve(undefined);
            } },
            React.createElement(FontAwesome, { color: isReset ? theme.dangerText : theme.warningText, name: "exclamation-triangle", size: theme.rem(1.5), style: styles.rowIcon }),
            React.createElement(Text, { style: styles.rowText },
                React.createElement(Text, { style: styles.bold },
                    isReset
                        ? s.strings.alert_modal_reset
                        : s.strings.alert_modal_voucher,
                    username),
                s.strings.alert_modal_action),
            React.createElement(AntDesignIcon, { color: theme.iconTappable, name: "right", size: theme.rem(1), style: styles.rowIcon })));
    }
}
const getStyles = cacheStyles((theme) => ({
    row: {
        alignItems: 'center',
        flexDirection: 'row'
    },
    rowBorder: {
        alignItems: 'center',
        borderTopColor: theme.lineDivider,
        borderTopWidth: theme.thinLineWidth,
        flexDirection: 'row',
        marginTop: theme.rem(0.5),
        paddingTop: theme.rem(0.5)
    },
    rowIcon: {
        margin: theme.rem(0.5)
    },
    rowText: {
        color: theme.primaryText,
        flexGrow: 1,
        flexShrink: 1,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        margin: theme.rem(0.5)
    },
    bold: {
        fontWeight: 'bold'
    }
}));
export const SecurityAlertsModal = withTheme(SecurityAlertsModalComponent);
